commit - 2a29a72456b5b773b87413387c79b9b26b135ae9
commit + b61207742f1746c695838076434caadeed528ca4
blob - b9b8fc26d30f731386f8895b32bcb9a9b71a5178
blob + f7daea1df2c5a16fffe11ba861ac4c7337b7aefc
--- src/ngircd/tool.c
+++ src/ngircd/tool.c
* Naehere Informationen entnehmen Sie bitter der Datei COPYING. Eine Liste
* der an comBase beteiligten Autoren finden Sie in der Datei AUTHORS.
*
- * $Id: tool.c,v 1.2 2001/12/12 17:20:33 alex Exp $
+ * $Id: tool.c,v 1.3 2001/12/29 03:05:34 alex Exp $
*
* tool.c: Hilfsfunktionen, ggf. Platformabhaengig
*
* $Log: tool.c,v $
+ * Revision 1.3 2001/12/29 03:05:34 alex
+ * - Funktionsnamen etwas konsequenter umbenannt :-)
+ *
* Revision 1.2 2001/12/12 17:20:33 alex
* - Tool-Funktionen haben nun das Praefix "ngt_".
*
#include "tool.h"
-GLOBAL VOID ngt_Trim_Str( CHAR *String )
+GLOBAL VOID ngt_TrimStr( CHAR *String )
{
/* Mit ngt_Trim_Str() werden fuehrende und folgende Leerzeichen,
* Tabulatoren und Zeilenumbrueche (ASCII 10 und ASCII 13) aus
* dem String entfernt. */
*(++ptr) = '\0';
memmove( String, start, strlen( start ) + 1 );
-} /* ngt_Trim_Str */
+} /* ngt_TrimStr */
/* -eof- */
@@
{
- /* Mit ngt_Trim_Str() werden fuehrende und folgende Leerzeichen,
+ /* Mit ngt_TrimStr() werden fuehrende und folgende Leerzeichen,
* Tabulatoren und Zeilenumbrueche (ASCII 10 und ASCII 13) aus
* dem String entfernt. */